changeset 79385:96dc85a06a3a

(set-locale-environment): Set default-file-name-coding-system from system defaults on Windows.
author Jason Rumney <jasonr@gnu.org>
date Wed, 14 Nov 2007 10:22:33 +0000
parents 7420ede9df33
children 892ada09f044
files lisp/international/mule-cmds.el
diffstat 1 files changed, 3 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/mule-cmds.el	Wed Nov 14 09:05:26 2007 +0000
+++ b/lisp/international/mule-cmds.el	Wed Nov 14 10:22:33 2007 +0000
@@ -2609,12 +2609,13 @@
 	  (setq locale-coding-system coding-system))))
 
     ;; On Windows, override locale-coding-system,
     ;; keyboard-coding-system with system codepage.  Note:
     ;; selection-coding-system is already set in w32select.c.
     (when (boundp 'w32-ansi-code-page)
       (let ((code-page-coding (intern (format "cp%d" w32-ansi-code-page))))
 	(when (coding-system-p code-page-coding)
 	  (setq locale-coding-system code-page-coding)
+          (setq default-file-name-coding-system code-page-coding)
 	  (set-keyboard-coding-system code-page-coding)
 	  (set-terminal-coding-system code-page-coding))))
@@ -2609,12 +2609,13 @@
 
     ;; On Windows, override locale-coding-system,
-    ;; keyboard-coding-system with system codepage.  Note:
-    ;; selection-coding-system is already set in w32select.c.
+    ;; default-file-name-coding-system, keyboard-coding-system,
+    ;; terminal-coding-system with system codepage.
     (when (boundp 'w32-ansi-code-page)
       (let ((code-page-coding (intern (format "cp%d" w32-ansi-code-page))))